package cn.com.ctop.job.kuaishou.handler;

import cn.com.ctop.job.kuaishou.data.entity.CompassBindAdvertisers;
import cn.com.ctop.job.kuaishou.data.service.CompassBindAdvertisersService;
import cn.com.ctop.job.kuaishou.data.service.IKuaishouVideoListService;
import cn.com.ctop.job.kuaishou.data.service.IOauthTokenService;
import cn.com.ctop.job.kuaishou.data.utils.Check;
import cn.com.ctop.job.kuaishou.data.utils.DateUtils;
import com.xxl.job.core.context.XxlJobHelper;
import com.xxl.job.core.handler.annotation.XxlJob;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

@Slf4j
@Component
public class CompassBindAdvertisersJob {
    @Autowired
    private IOauthTokenService tokenService;
    @Autowired
    private CompassBindAdvertisersService compassBindAdvertisersService;

    private static ExecutorService campaignExecutorService = Executors.newFixedThreadPool(3);
    private static ExecutorService unitExecutorService = Executors.newFixedThreadPool(3);

    /**
     * 获取罗盘绑定广告主列
     * 当前快手ID,账户ID 固定写死
     */

    @XxlJob("compassAdvertisers")
    public void compassAdvertisers() throws Exception {
        //罗盘账户的「快手 id」，只能传递授权时使用的快手 id
        Long advertiserId = 4361966075L;
        String token = tokenService.getOuthTokenAccountId(39526067L);
        compassBindAdvertisersService.openapiGwUcV1Advertisers(advertiserId, token);
        log.info("------【获取罗盘绑定广告主列】执行完成");

    }

    private String getToken(String accountId) {
        CompassBindAdvertisers advertiser = compassBindAdvertisersService.getByAccountId(accountId);
        if (Check.isNull(advertiser)) {
            return null;
        }
        String token = null;
        String advertiserName = advertiser.getAdvertiserName();
        if (!Check.isNull(advertiserName) && advertiserName.contains("汇创")) {
            //汇创
            token = tokenService.getAgentTokenByAgentId(14L);
        } else {
            //723 骄阳token
            token = tokenService.getAgentTokenByAgentId(723L);
        }
        return token;
    }

    /**
     * 获取罗盘绑定广告主今日计划日报表
     */
    @XxlJob("compassAdNowDayCampaignDailyReport")
    public void compassAdNowDayCampaignDailyReport() throws Exception {
        String accountId = XxlJobHelper.getJobParam(); // 执行参数
        if (Check.isNull(accountId)) {
            log.error("入参为空");
            return;
        }
        String token = getToken(accountId);
        if (Check.isNull(token)) {
            log.error("token 为空 ！！！");
            return;
        }
        String nowDate = DateUtils.getNowDate("yyyy-MM-dd");
        campaignExecutorService.submit(
                new Runnable() {
                    @Override
                    public void run() {
                        compassBindAdvertisersService.getCompassAdvertisersCampaignReportDaily(
                                Long.valueOf(accountId), token, nowDate, nowDate, 1);
                    }
                });
    }

    /**
     * 获取罗盘绑定广告主昨日日计划日报表
     */
    @XxlJob("compassAdYesterdayCampaignDailyReport")
    public void compassAdYesterdayCampaignDailyReport() throws Exception {
        String accountId = XxlJobHelper.getJobParam(); // 执行参数
        if (Check.isNull(accountId)) {
            log.error("入参为空");
            return;
        }
        String token = getToken(accountId);
        if (Check.isNull(token)) {
            log.error("token 为空 ！！！");
            return;
        }
        String nowDate = DateUtils.getNowDate("yyyy-MM-dd");
        String yesterday = DateUtils.getAnotherDay("yyyy-MM-dd", nowDate, -1);
        campaignExecutorService.submit(
                new Runnable() {
                    @Override
                    public void run() {
                        compassBindAdvertisersService.getCompassAdvertisersCampaignReportDaily(
                                Long.valueOf(accountId), token, yesterday, yesterday, 1);
                    }
                });
    }

    /**
     * 获取罗盘绑定广告主今日广告组日报表
     */
    @XxlJob("compassAdNowDayUnitDailyReport")
    public void compassAdNowDayUnitDailyReport() throws Exception {
        String accountId = XxlJobHelper.getJobParam(); // 执行参数
        if (Check.isNull(accountId)) {
            log.error("入参为空");
            return;
        }

        String token = getToken(accountId);
        if (Check.isNull(token)) {
            log.error("token 为空 ！！！");
            return;
        }
        String nowDate = DateUtils.getNowDate("yyyy-MM-dd");
        campaignExecutorService.submit(
                new Runnable() {
                    @Override
                    public void run() {
                        compassBindAdvertisersService.getCompassAdvertisersUnitReportDaily(
                                Long.valueOf(accountId), token, nowDate, nowDate, 1);
                    }
                });
    }

    /**
     * 获取罗盘绑定广告主昨日广告组日报表
     */
    @XxlJob("compassAdYesterdayUnitDailyReport")
    public void compassAdYesterdayUnitDailyReport() throws Exception {
        String accountId = XxlJobHelper.getJobParam(); // 执行参数
        if (Check.isNull(accountId)) {
            log.error("入参为空");
            return;
        }
        String token = getToken(accountId);
        if (Check.isNull(token)) {
            log.error("token 为空 ！！！");
            return;
        }
        String nowDate = DateUtils.getNowDate("yyyy-MM-dd");
        String yesterday = DateUtils.getAnotherDay("yyyy-MM-dd", nowDate, -1);
        campaignExecutorService.submit(
                new Runnable() {
                    @Override
                    public void run() {
                        compassBindAdvertisersService.getCompassAdvertisersUnitReportDaily(
                                Long.valueOf(accountId), token, yesterday, yesterday, 1);
                    }
                });
    }

    /**
     * 获取罗盘绑定广告主今日素材日报表
     */
    @XxlJob("compassAdNowDayVideosDailyReport")
    public void compassAdNowDayVideosDailyReport() throws Exception {
        String accountId = XxlJobHelper.getJobParam(); // 执行参数
        if (Check.isNull(accountId)) {
            log.error("入参为空");
            return;
        }

        String token = getToken(accountId);
        if (Check.isNull(token)) {
            log.error("token 为空 ！！！");
            return;
        }
        String nowDate = DateUtils.getNowDate("yyyy-MM-dd");
        campaignExecutorService.submit(
                new Runnable() {
                    @Override
                    public void run() {
                        compassBindAdvertisersService.getCompassAdvertisersVideosReportDaily(
                                Long.valueOf(accountId), token, nowDate, nowDate, 1);
                    }
                });
    }

    /**
     * 获取罗盘绑定广告主昨日素材日报表
     */
    @XxlJob("compassAdYesterdayVideosDailyReport")
    public void compassAdYesterdayVideosDailyReport() throws Exception {
        String accountId = XxlJobHelper.getJobParam(); // 执行参数
        if (Check.isNull(accountId)) {
            log.error("入参为空");
            return;
        }
        String token = getToken(accountId);
        if (Check.isNull(token)) {
            log.error("token 为空 ！！！");
            return;
        }
        String nowDate = DateUtils.getNowDate("yyyy-MM-dd");
        String yesterday = DateUtils.getAnotherDay("yyyy-MM-dd", nowDate, -1);
        campaignExecutorService.submit(
                new Runnable() {
                    @Override
                    public void run() {
                        compassBindAdvertisersService.getCompassAdvertisersVideosReportDaily(
                                Long.valueOf(accountId), token, yesterday, yesterday, 1);
                    }
                });
    }


    private static ExecutorService nowExecutorService = Executors.newFixedThreadPool(5);

    @Autowired
    private IKuaishouVideoListService videoListService;

    /**
     * 当日视频物料
     *
     * @throws Exception
     */
    @XxlJob("compassNowDayVideoList")
    public void compassNowDayVideoList() throws Exception {
        String accountId = XxlJobHelper.getJobParam(); // 执行参数
        if (Check.isNull(accountId)) {
            log.error("入参为空");
            return;
        }
        String token = getToken(accountId);
        if (Check.isNull(token)) {
            log.error("token 为空 ！！！");
            return;
        }
        String nowDate = DateUtils.getNowDate("yyyy-MM-dd");
        nowExecutorService.submit(
                new Runnable() {
                    @Override
                    public void run() {
                        compassBindAdvertisersService.getVideoList(Long.valueOf(accountId), token, nowDate, nowDate, 1);
                    }
                });
    }

    /**
     * 昨天日视频物料
     *
     * @throws Exception
     */
    @XxlJob("compassYesterdayVideoList")
    public void compassYesterdayVideoList() throws Exception {
        String accountId = XxlJobHelper.getJobParam(); // 执行参数
        if (Check.isNull(accountId)) {
            log.error("入参为空");
            return;
        }
        String token = getToken(accountId);
        if (Check.isNull(token)) {
            log.error("token 为空 ！！！");
            return;
        }
        String nowDate = DateUtils.getNowDate("yyyy-MM-dd");
        String yesterday = DateUtils.getAnotherDay("yyyy-MM-dd", nowDate, -1);
        nowExecutorService.submit(
                new Runnable() {
                    @Override
                    public void run() {
                        compassBindAdvertisersService.getVideoList(Long.valueOf(accountId), token, yesterday, yesterday, 1);
                    }
                });
    }

    /**
     * 无时间，取全部
     *
     * @throws Exception
     */
    @XxlJob("compassAllVideoList")
    public void compassAllVideoList() throws Exception {
        String accountId = XxlJobHelper.getJobParam(); // 执行参数
        if (Check.isNull(accountId)) {
            log.error("入参为空");
            return;
        }
        String token = getToken(accountId);
        if (Check.isNull(token)) {
            log.error("token 为空 ！！！");
            return;
        }
        nowExecutorService.submit(
                new Runnable() {
                    @Override
                    public void run() {
                        compassBindAdvertisersService.getVideoList(Long.valueOf(accountId), token, null, null, 1);
                    }
                });
    }
}
